@@ -1,6 +1,6 @@
 package Hubot::Scripts::blacklist;
 {
-  $Hubot::Scripts::blacklist::VERSION = '0.1.7';
+  $Hubot::Scripts::blacklist::VERSION = '0.1.8';
 }
 use strict;
 use warnings;
@@ -9,20 +9,24 @@ use Try::Tiny;
 sub load {
     my ( $class, $robot ) = @_;
     $robot->brain->{data}{blacklist}{subscriber} ||= {};
-    $robot->brain->{data}{blacklist}{patterns} ||= [];
-    print STDERR "you have to set env HUBOT_BLACKLIST_MANAGER" unless $ENV{HUBOT_BLACKLIST_MANAGER};
+    $robot->brain->{data}{blacklist}{patterns}   ||= [];
+    print STDERR "you have to set env HUBOT_BLACKLIST_MANAGER"
+        unless $ENV{HUBOT_BLACKLIST_MANAGER};
     $robot->respond(
         qr/blacklist add (.*)$/i,
         sub {
             my $msg = shift;
 
-            return unless checkPermission($robot, $msg);
+            return unless checkPermission( $robot, $msg );
 
             my $pattern = $msg->match->[0];
             try {
-                qr/$pattern/ and push @{ $robot->brain->{data}{blacklist}{patterns} }, $pattern;
+                qr/$pattern/
+                    and push @{ $robot->brain->{data}{blacklist}{patterns} },
+                    $pattern;
                 $msg->send("OK, added <$pattern> to blacklist");
-            } catch {
+            }
+            catch {
                 $msg->send("Failed to add <$pattern> to blacklist: $_");
             };
         }
@@ -31,9 +35,9 @@ sub load {
     $robot->respond(
         qr/blacklist$/i,
         sub {
-            my $msg = shift;
+            my $msg   = shift;
             my $match = $msg->match->[0];
-            my @list = @{ $robot->brain->{data}{blacklist}{patterns} };
+            my @list  = @{ $robot->brain->{data}{blacklist}{patterns} };
             if (@list) {
                 my $index = 0;
                 map {
@@ -41,7 +45,8 @@ sub load {
                     $index++;
                 } @list;
                 $msg->send(@list);
-            } else {
+            }
+            else {
                 $msg->send('no blacklist');
             }
         }
@@ -52,13 +57,14 @@ sub load {
         sub {
             my $msg = shift;
 
-            return unless checkPermission($robot, $msg);
+            return unless checkPermission( $robot, $msg );
 
             my $index = $msg->match->[0];
-            my @list = @{ $robot->brain->{data}{blacklist}{patterns} };
-            if ($index > @list - 1) {
+            my @list  = @{ $robot->brain->{data}{blacklist}{patterns} };
+            if ( $index > @list - 1 ) {
                 $msg->send("Can't delete [$index] from blacklist");
-            } else {
+            }
+            else {
                 my $pattern = splice @list, $index, 1;
                 $msg->send("Deleted [$index] - <$pattern> from blacklist");
                 $robot->brain->{data}{blacklist}{patterns} = \@list;
@@ -69,7 +75,7 @@ sub load {
     $robot->respond(
         qr/blacklist subscribe$/i,
         sub {
-            my $msg = shift;
+            my $msg  = shift;
             my $name = $msg->message->user->{name};
             $robot->brain->{data}{blacklist}{subscriber}{$name}++;
             $msg->send("OK, $name subscribes blacklist");
@@ -79,7 +85,7 @@ sub load {
     $robot->respond(
         qr/blacklist unsubscribe$/i,
         sub {
-            my $msg = shift;
+            my $msg  = shift;
             my $name = $msg->message->user->{name};
             delete $robot->brain->{data}{blacklist}{subscriber}{$name};
             $msg->send("OK, $name unsubscribes blacklist");
@@ -88,16 +94,19 @@ sub load {
 
     $robot->enter(
         sub {
-            my $msg = shift;
+            my $msg  = shift;
             my $user = $msg->message->user->{name};
             ## support IRC adapter only
-            if ('Hubot::Adapter::Irc' eq ref $robot->adapter) {
+            if ( 'Hubot::Adapter::Irc' eq ref $robot->adapter ) {
                 my $whois = $robot->adapter->whois($user);
-                for my $pattern (@{ $robot->brain->{data}{blacklist}{patterns} }) {
+                for my $pattern (
+                    @{ $robot->brain->{data}{blacklist}{patterns} } )
+                {
                     my $regex = qr/$pattern/;
-                    if ($whois =~ m/$regex/) {
-                        my @subscriber = keys %{ $robot->brain->{data}{blacklist}{subscriber} };
-                        notify($robot, $msg, $pattern, @subscriber);
+                    if ( $whois =~ m/$regex/ ) {
+                        my @subscriber = keys
+                            %{ $robot->brain->{data}{blacklist}{subscriber} };
+                        notify( $robot, $msg, $pattern, @subscriber );
                         last;
                     }
                 }
@@ -107,16 +116,20 @@ sub load {
 }
 
 sub checkPermission {
-    my ($robot, $msg) = @_;
+    my ( $robot, $msg ) = @_;
     my @manager = split /,/, $ENV{HUBOT_BLACKLIST_MANAGER} || '';
     unless (@manager) {
-        $msg->send("oops! no managers. " . $robot->name . "'s owner has to read the documentation");
+        $msg->send( "oops! no managers. "
+                . $robot->name
+                . "'s owner has to read the documentation" );
         return;
     }
 
     my $name = $msg->message->user->{name};
-    unless (grep { /$name/ } @manager) {
-        $msg->send("you don't have permission. to add blacklist, asking to managers: $ENV{HUBOT_BLACKLIST_MANAGER}");
+    unless ( grep {/$name/} @manager ) {
+        $msg->send(
+            "you don't have permission. to add blacklist, asking to managers: $ENV{HUBOT_BLACKLIST_MANAGER}"
+        );
         return;
     }
 
@@ -124,10 +137,10 @@ sub checkPermission {
 }
 
 sub notify {
-    my ($robot, $res, $patt, @subs) = @_;
+    my ( $robot, $res, $patt, @subs ) = @_;
     for my $sub (@subs) {
         my $to = $robot->userForName($sub);
-        $res->whisper($to, "blacklist[$patt] joined channel");
+        $res->whisper( $to, "blacklist[$patt] joined channel" );
     }
 }
 
@@ -137,6 +150,10 @@ sub notify {
 
 Hubot::Scripts::blacklist
 
+=head1 VERSION
+
+version 0.1.8
+
 =head1 SYNOPSIS
 
     hubot blacklist - show blacklist
