@@ -1,6 +1,6 @@
 package Hubot::Scripts::op;
 {
-  $Hubot::Scripts::op::VERSION = '0.1.7';
+  $Hubot::Scripts::op::VERSION = '0.1.8';
 }
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ sub load {
     my ( $class, $robot ) = @_;
 
     my $nickserv = $ENV{HUBOT_IRC_NICKSERV} || 'NickServ';
-    my @allow_accounts = split(/,/, $ENV{HUBOT_OP_ACCOUNTS} || '');
+    my @allow_accounts = split( /,/, $ENV{HUBOT_OP_ACCOUNTS} || '' );
     my $room = '';
 
     $robot->enter(
@@ -19,10 +19,10 @@ sub load {
             $room = $msg->message->user->{room};
             my $user = $msg->message->user->{name};
             ## support IRC adapter only
-            if ('Hubot::Adapter::Irc' eq ref $robot->adapter) {
+            if ( 'Hubot::Adapter::Irc' eq ref $robot->adapter ) {
                 my $to = $robot->userForName($nickserv);
                 ## maybe need more common interface for adapters
-                $robot->adapter->irc->send_srv('WHOIS' => $user);
+                $robot->adapter->irc->send_srv( 'WHOIS' => $user );
             }
         }
     );
@@ -32,12 +32,15 @@ sub load {
             my $msg = shift;
 
             my $text = $msg->message->text;
-            if (my ($nick, $account) = $text =~ m/^([^ ]+) is logged in as (.+)$/) {
+            if ( my ( $nick, $account )
+                = $text =~ m/^([^ ]+) is logged in as (.+)$/ )
+            {
                 ## freenode only?
                 return unless grep { $account eq $_ } @allow_accounts;
-                if ($robot->mode eq '+o') {
+                if ( $robot->mode eq '+o' ) {
                     ## maybe need more common interface for adapters
-                    $robot->adapter->irc->send_srv('MODE', $room, '+o', $nick);
+                    $robot->adapter->irc->send_srv( 'MODE', $room, '+o',
+                        $nick );
                 }
             }
         }
@@ -50,6 +53,10 @@ sub load {
 
 Hubot::Scripts::op
 
+=head1 VERSION
+
+version 0.1.8
+
 =head1 SYNOPSIS
 
     op - hubot will `/op <nick>` to configured account if hubot can
