@@ -1,6 +1,6 @@
 package Hubot::Scripts::tell;
 {
-  $Hubot::Scripts::tell::VERSION = '0.1.7';
+  $Hubot::Scripts::tell::VERSION = '0.1.8';
 }
 use strict;
 use warnings;
@@ -15,19 +15,20 @@ sub load {
             my $sender = $msg->message->user->{name};
             my ( $post, $recipient ) = ( $msg->match->[0], $msg->match->[1] );
 
-            # XXX: hey, There should be generalized nick matchers, supplied from each adapters.
-            # $robot->exist($room, $nick)
+# XXX: hey, There should be generalized nick matchers, supplied from each adapters.
+# $robot->exist($room, $nick)
             if ( my ($user) = $robot->userForName($recipient)
                 and $msg->exist($recipient) )
             {
                 $msg->reply("<$recipient> $post");
             }
             else {
-                # XXX: hey, There is no time provided from adapters for messages.
+              # XXX: hey, There is no time provided from adapters for messages.
                 my $dt = DateTime->now( time_zone => 'Asia/Seoul' );
-                $robot->brain->{data}{tell}{$recipient}{ +time } =
-                  [ $sender, $recipient, $post, $dt->ymd . " " . $dt->hms ];
-                $msg->reply("OK, I'll pass that on when $recipient is around.");
+                $robot->brain->{data}{tell}{$recipient}{ +time }
+                    = [$sender, $recipient, $post, $dt->ymd . " " . $dt->hms];
+                $msg->reply(
+                    "OK, I'll pass that on when $recipient is around.");
             }
         }
     );
@@ -57,6 +58,10 @@ sub load {
 
 Hubot::Scripts::tell
 
+=head1 VERSION
+
+version 0.1.8
+
 =head1 SYNOPSIS
 
     hubot tell <user> <message> - pass <message> on when <user> is around.
